#ifndef KAPPWIDGETMANAGER_H
#define KAPPWIDGETMANAGER_H

#include "libukui-appwidget-manager_global.h"

#include <QDBusInterface>

namespace AppWidget
{
/**
 * @defgroup 小插件管理服务接口模块
 */

/**
 * @brief 小插件属性枚举
 */
enum AppWidgetConfig {
    NAME = 1,                //小插件名字
    PROVIDER_NAME,           //提供端名
    PREVIEW_PATH,            //预览图
    ZOOM,                    //是否支持缩放
    RIGHT_BUTTON,            //是否支持右键
    REPEAT_PLACEMENT,        //是否可以重复放置
    MIN_WIDTH,               //最小宽度
    MIN_HEIGHT,              //最小高度
    TARGET_CELL_WIDTH,       //小插件默认宽度所占屏幕的单位格数
    TARGET_CELL_HEIGHT,      //小插件默认高度所占屏幕的单位格数
    UPDATE_PERIODMILLIS,     //是否定时更新
    DESCRIBE,                //小插件描述
};

class LIBUKUIAPPWIDGETMANAGER_EXPORT KAppWidgetManager : public QDBusInterface
{
    Q_OBJECT
public:
    KAppWidgetManager(QObject *parent = nullptr);
    /**
     * @brief 获取小插件列表
     * @return app widget list
     */
    QStringList getAppWidgetList();
    /**
     * @brief 获取小插件ui文件路径
     * @param appwidgetname
     * @return path of ui file
     */
    QString getAppWidgetUiFile(const QString &appwidgetname);
    /**
     * @brief 获取小插件的config属性
     * @param appwidgetname config
     * @return config value of appwidgetname
     */
    QString getAppWidgetConfig(const QString &appwidgetname, const AppWidgetConfig& config);
    /**
     * @brief 获取小插件的所有属性
     * @param appwidgetname
     * @return config list of widget
     */
    QMap<QString,QVariant> getAppWidgetConfigs(const QString &appwidgetname);
    /**
     * @brief 注册小插件
     * @param appwidgetname username
     * @return appwidget id
     */
    int registerAppWidget(const QString &appwidgetname, const QString &username);
    /**
     * @brief 注销小插件
     * @param appwidgetid
     * @return unregister success return true, else false
     */
    bool unregisterAppWidget(const int &appwidgetid);
    /**
     * @brief 获取小插件共享数据
     * @param appwidgetid
     * @return data from provider
     */
    QMap<QString, QVariant> getAppWidgetData(const int &appwidgetid);
    /**
     * @brief 更新小插件共享数据
     * @param providername data
     */
    void updateAppWidget(const QString &providername, const QMap<QString, QVariant> &data);

    /**
     * @brief 转换KAppWidgetCommon::AppWidgetConfig枚举为字符串
     * @param KAppWidgetCommon::AppWidgetConfig config
     * @return config of string
     */
    static QString enumToSTring(const AppWidgetConfig& config);

signals:
    /**
     * @brief 小插件资源文件增加信号
     * @param appwidget name
     */
    void appWidgetFileAdded(const QString &appwidgetname);
    /**
     * @brief 小插件资源文件删除信号
     * @param appwidget name
     */
    void appWidgetFileDeleted (const QString &appwidgetname);

};
}// namespace AppWidget


#endif // KAPPWIDGETMANAGER_H
